@@ -98,28 +98,23 @@ class LoggingAssertionMixin:
     def assertLogRecord(
         self,
         logger_cm,
+        level,
         msg,
-        levelno,
         status_code,
-        request=None,
         exc_class=None,
     ):
         self.assertEqual(
             records_len := len(logger_cm.records),
             1,
-            f"Wrong number of calls for {logger_cm=} in {levelno=} (expected 1, got "
+            f"Wrong number of calls for {logger_cm=} in {level=} (expected 1, got "
             f"{records_len}).",
         )
         record = logger_cm.records[0]
         self.assertEqual(record.getMessage(), msg)
-        self.assertEqual(record.levelno, levelno)
         self.assertEqual(record.status_code, status_code)
-        if request is not None:
-            self.assertEqual(record.request, request)
         if exc_class:
             self.assertIsNotNone(record.exc_info)
             self.assertEqual(record.exc_info[0], exc_class)
-        return record
 
     def assertLogsRequest(
         self, url, level, msg, status_code, logger="django.request", exc_class=None
@@ -129,9 +124,7 @@ class LoggingAssertionMixin:
                 self.client.get(url)
             except views.UncaughtException:
                 pass
-            self.assertLogRecord(
-                cm, msg, getattr(logging, level), status_code, exc_class=exc_class
-            )
+            self.assertLogRecord(cm, level, msg, status_code, exc_class)
 
 
 @override_settings(DEBUG=True, ROOT_URLCONF="logging_tests.urls")
@@ -163,17 +156,21 @@ class HandlerLoggingTests(
         )
 
     async def test_async_page_not_found_warning(self):
-        with self.assertLogs("django.request", "WARNING") as cm:
+        logger = "django.request"
+        level = "WARNING"
+        with self.assertLogs(logger, level) as cm:
             await self.async_client.get("/does_not_exist/")
 
-        self.assertLogRecord(cm, "Not Found: /does_not_exist/", logging.WARNING, 404)
+        self.assertLogRecord(cm, level, "Not Found: /does_not_exist/", 404)
 
     async def test_async_control_chars_escaped(self):
-        with self.assertLogs("django.request", "WARNING") as cm:
+        logger = "django.request"
+        level = "WARNING"
+        with self.assertLogs(logger, level) as cm:
             await self.async_client.get(r"/%1B[1;31mNOW IN RED!!!1B[0m/")
 
         self.assertLogRecord(
-            cm, r"Not Found: /\x1b[1;31mNOW IN RED!!!1B[0m/", logging.WARNING, 404
+            cm, level, r"Not Found: /\x1b[1;31mNOW IN RED!!!1B[0m/", 404
         )
 
     def test_page_not_found_raised(self):
@@ -510,7 +507,7 @@ class AdminEmailHandlerTest(SimpleTestCase):
         msg = mail.outbox[0]
         self.assertEqual(msg.subject, "[Django] ERROR: message")
         self.assertEqual(len(msg.alternatives), 1)
-        body_html = str(msg.alternatives[0][0])
+        body_html = str(msg.alternatives[0].content)
         self.assertIn('<div id="traceback">', body_html)
         self.assertNotIn("<form", body_html)
 
@@ -618,15 +615,6 @@ class SecurityLoggerTest(LoggingAssertionMixin, SimpleTestCase):
         self.assertEqual(len(mail.outbox), 1)
         self.assertIn("SuspiciousOperation at /suspicious/", mail.outbox[0].body)
 
-    def test_response_logged(self):
-        with self.assertLogs("django.security.SuspiciousOperation", "ERROR") as handler:
-            response = self.client.get("/suspicious/")
-
-        self.assertLogRecord(
-            handler, "dubious", logging.ERROR, 400, request=response.wsgi_request
-        )
-        self.assertEqual(response.status_code, 400)
-
 
 class SettingsCustomLoggingTest(AdminScriptTestCase):
     """
@@ -719,10 +707,24 @@ class LogFormattersTests(SimpleTestCase):
             )
 
 
-class LogResponseRealLoggerTests(LoggingAssertionMixin, TestCase):
+class LogResponseRealLoggerTests(TestCase):
 
     request = RequestFactory().get("/test-path/")
 
+    def assertResponseLogged(self, logger_cm, msg, levelno, status_code, request):
+        self.assertEqual(
+            records_len := len(logger_cm.records),
+            1,
+            f"Unexpected number of records for {logger_cm=} in {levelno=} (expected 1, "
+            f"got {records_len}).",
+        )
+        record = logger_cm.records[0]
+        self.assertEqual(record.getMessage(), msg)
+        self.assertEqual(record.levelno, levelno)
+        self.assertEqual(record.status_code, status_code)
+        self.assertEqual(record.request, request)
+        return record
+
     def test_missing_response_raises_attribute_error(self):
         with self.assertRaises(AttributeError):
             log_response("No response provided", response=None, request=self.request)
@@ -731,7 +733,7 @@ class LogResponseRealLoggerTests(LoggingAssertionMixin, TestCase):
         response = HttpResponse(status=403)
         with self.assertLogs("django.request", level="INFO") as cm:
             log_response(msg := "Missing request", response=response, request=None)
-        self.assertLogRecord(cm, msg, logging.WARNING, 403, request=None)
+        self.assertResponseLogged(cm, msg, logging.WARNING, 403, request=None)
 
     def test_logs_5xx_as_error(self):
         response = HttpResponse(status=508)
@@ -739,7 +741,7 @@ class LogResponseRealLoggerTests(LoggingAssertionMixin, TestCase):
             log_response(
                 msg := "Server error occurred", response=response, request=self.request
             )
-        self.assertLogRecord(cm, msg, logging.ERROR, 508, self.request)
+        self.assertResponseLogged(cm, msg, logging.ERROR, 508, self.request)
 
     def test_logs_4xx_as_warning(self):
         response = HttpResponse(status=418)
@@ -747,13 +749,13 @@ class LogResponseRealLoggerTests(LoggingAssertionMixin, TestCase):
             log_response(
                 msg := "This is a teapot!", response=response, request=self.request
             )
-        self.assertLogRecord(cm, msg, logging.WARNING, 418, self.request)
+        self.assertResponseLogged(cm, msg, logging.WARNING, 418, self.request)
 
     def test_logs_2xx_as_info(self):
         response = HttpResponse(status=201)
         with self.assertLogs("django.request", level="INFO") as cm:
             log_response(msg := "OK response", response=response, request=self.request)
-        self.assertLogRecord(cm, msg, logging.INFO, 201, self.request)
+        self.assertResponseLogged(cm, msg, logging.INFO, 201, self.request)
 
     def test_custom_log_level(self):
         response = HttpResponse(status=403)
@@ -764,14 +766,14 @@ class LogResponseRealLoggerTests(LoggingAssertionMixin, TestCase):
                 request=self.request,
                 level="debug",
             )
-        self.assertLogRecord(cm, msg, logging.DEBUG, 403, self.request)
+        self.assertResponseLogged(cm, msg, logging.DEBUG, 403, self.request)
 
     def test_logs_only_once_per_response(self):
         response = HttpResponse(status=500)
         with self.assertLogs("django.request", level="ERROR") as cm:
             log_response("First log", response=response, request=self.request)
             log_response("Second log", response=response, request=self.request)
-        self.assertLogRecord(cm, "First log", logging.ERROR, 500, self.request)
+        self.assertResponseLogged(cm, "First log", logging.ERROR, 500, self.request)
 
     def test_exc_info_output(self):
         response = HttpResponse(status=500)
@@ -785,7 +787,9 @@ class LogResponseRealLoggerTests(LoggingAssertionMixin, TestCase):
                     request=self.request,
                     exception=exc,
                 )
-        self.assertLogRecord(cm, "With exception", logging.ERROR, 500, self.request)
+        self.assertResponseLogged(
+            cm, "With exception", logging.ERROR, 500, self.request
+        )
         self.assertIn("ValueError", "\n".join(cm.output))  # Stack trace included
 
     def test_format_args_are_applied(self):
@@ -799,7 +803,7 @@ class LogResponseRealLoggerTests(LoggingAssertionMixin, TestCase):
                 request=self.request,
             )
         msg = "Something went wrong: DB error (42)"
-        self.assertLogRecord(cm, msg, logging.ERROR, 500, self.request)
+        self.assertResponseLogged(cm, msg, logging.ERROR, 500, self.request)
 
     def test_logs_with_custom_logger(self):
         handler = logging.StreamHandler(log_stream := StringIO())
@@ -873,7 +877,7 @@ class LogResponseRealLoggerTests(LoggingAssertionMixin, TestCase):
                 response = HttpResponse(status=318)
                 log_response(msg, case, response=response, level="error")
 
-                record = self.assertLogRecord(
+                record = self.assertResponseLogged(
                     cm,
                     msg % expected,
                     levelno=logging.ERROR,
